pub struct RecentSyncLengths {
sender: Sender<Vec<usize>>,
recent_lengths: Vec<usize>,
}Expand description
A helper type which holds a list of recent syncer response lengths. These sync lengths can be used to work out if Zebra has reached the end of the chain.
New lengths are added to the front of the list.
Old lengths are dropped if the list is longer than MAX_RECENT_LENGTHS.
Fields
sender: Sender<Vec<usize>>A sender for an array of recent sync lengths.
recent_lengths: Vec<usize>A local copy of the contents of sender.
Implementations
Sourceimpl RecentSyncLengths
impl RecentSyncLengths
Sourcepub const MAX_RECENT_LENGTHS: usize = 3
pub const MAX_RECENT_LENGTHS: usize = 3
The maximum number of lengths sent by RecentSyncLengths.
Older lengths are dropped.
This length was chosen as a tradeoff between:
- clearing temporary errors and temporary syncs quickly
- distinguishing between temporary and sustained syncs/errors
- activating the syncer shortly after reaching the chain tip
Sourcepub fn new() -> (Self, Receiver<Vec<usize>>)
pub fn new() -> (Self, Receiver<Vec<usize>>)
Create a new instance of RecentSyncLengths
and a [watch::Receiver] endpoint for receiving recent sync lengths.
Sourcepub fn push_obtain_tips_length(&mut self, sync_length: usize)
pub fn push_obtain_tips_length(&mut self, sync_length: usize)
Insert a sync length from ChainSync::obtain_tips at the front of the
list.
Sourcepub fn push_extend_tips_length(&mut self, sync_length: usize)
pub fn push_extend_tips_length(&mut self, sync_length: usize)
Insert a sync length from ChainSync::extend_tips at the front of the
list.